@@ -22,7 +22,7 @@ import nested_diff.handlers
 
 __all__ = ['Differ', 'Iterator', 'Patcher', 'diff', 'patch']
 
-__version__ = '0.14'
+__version__ = '0.15'
 __author__ = 'Michael Samoglyadov'
 __license__ = 'Apache License, Version 2.0'
 __website__ = 'https://github.com/mr-mixas/Nested-Diff.py'
@@ -43,7 +43,7 @@ TYPE_HANDLERS = (
 )
 
 
-class Differ(object):
+class Differ():
     """
     Compute recursive diff for two passed objects.
 
@@ -63,7 +63,7 @@ class Differ(object):
     and auxiliary keys:
 
     `C` comment; optional, value - arbitrary string.
-    `E` diffed entity (optional), value - empty instance of entity's class.
+    `E` extension ID (optional).
     `I` index for sequence item, used only when prior item was omitted.
 
     Diff metadata alternates with actual data; simple types specified as is,
@@ -104,17 +104,16 @@ class Differ(object):
 
     def __init__(self, A=True, N=True, O=True, R=True, U=True,  # noqa: E501 E741 N803
                  trimR=False, handlers=None):
-        """
-        Initialize Differ.
+        """Initialize Differ.
 
-        Optional arguments:
-        `A`, `N`, `O`, `R`, `U` are toggles for according diff ops and all
-        enabled (`True`) by default.
-
-        `trimR` when True will drop (replace by `None`) removed data from diff;
-        default is `False`.
-
-        `handlers` is a list of type handlers.
+        Args:
+            A: Enable/disable added items.
+            N: Enable/disable new items.
+            O: Enable/disable old items.
+            R: Enable/disable removed items.
+            U: Enable/disable unchanged items.
+            trimR: When enabled will replace removed data by None.
+            handlers: A list of type handlers.
 
         """
         self.op_a = A
@@ -130,15 +129,18 @@ class Differ(object):
             self.set_handler(handler)
 
     def diff(self, a, b):
-        """
-        Return equality flag and diff for two arbitrary objects.
+        """Calculate diff for two objects.
 
         This method calls registered handler according diffed objects type.
         Default handler called for objects with different types or when no
         handler registered for such type.
 
-        :param a: First object to diff.
-        :param b: Second object to diff.
+        Args:
+            a: First object to diff.
+            b: Second object to diff.
+
+        Returns:
+            Tuple: equality flag and nested diff.
 
         """
         if a is b:
@@ -153,28 +155,29 @@ class Differ(object):
         return self.default_differ(self, a, b)
 
     def set_handler(self, handler):
-        """
-        Set handler.
+        """Set handler.
 
-        :param handler: handlers.TypeHandler.
+        Args:
+            handler: Instance of handlers.TypeHandler.
 
         """
         self._differs[handler.handled_type] = handler.diff
 
 
-class Patcher(object):
+class Patcher():
     """Patch objects using nested diff."""
 
     default_patcher = DEFAULT_HANDLER.patch
 
     def __init__(self, handlers=None):
-        """
-        Initialize Patcher.
+        """Initialize Patcher.
 
-        :param handlers: List of type handlers.
+        Args:
+            handlers: List of type handlers.
 
         """
-        self._patchers = {}
+        self._patchers_by_cls = {}
+        self._patchers_by_ext = {}
 
         for handler in TYPE_HANDLERS if handlers is None else handlers:
             self.set_handler(handler)
@@ -183,81 +186,102 @@ class Patcher(object):
             self.set_handler(nested_diff.handlers.TextHandler())
 
     def patch(self, target, ndiff):
-        """
-        Return patched object.
+        """Patch object using nested diff.
 
         This method calls apropriate handler for target value according to
-        value type.
+        it's type.
 
-        :param target: Object to patch.
-        :param ndiff: Nested diff.
+        Args:
+            target: Object to patch.
+            ndiff: Nested diff.
+
+        Returns:
+            Patched object.
+
+        Raises:
+            ValueError: Unsupported patch type passed.
 
         """
         if 'D' in ndiff:
             try:
-                type_ = ndiff['E'].__class__
+                extension_id = ndiff['E']
+                try:
+                    patcher = self._patchers_by_ext[extension_id]
+                except KeyError:
+                    raise ValueError('unsupported extension: '
+                                     + extension_id) from None
             except KeyError:
-                type_ = ndiff['D'].__class__
+                cls = ndiff['D'].__class__
 
-            try:
-                return self._patchers[type_](self, target, ndiff)
-            except KeyError:
-                raise ValueError('unsupported patch type: '
-                                 + type_.__name__) from None
+                try:
+                    patcher = self._patchers_by_cls[cls]
+                except KeyError:
+                    raise ValueError('unsupported patch type: '
+                                     + cls.__name__) from None
+
+            return patcher(self, target, ndiff)
 
         return self.default_patcher(self, target, ndiff)
 
     def set_handler(self, handler):
-        """
-        Set handler.
+        """Set handler.
 
-        :param handler: handlers.TypeHandler.
+        Args:
+            handler: Instance of handlers.TypeHandler.
 
         """
-        self._patchers[handler.handled_type] = handler.patch
+        self._patchers_by_cls[handler.handled_type] = handler.patch
+
+        if handler.extension_id is not None:
+            self._patchers_by_ext[handler.extension_id] = handler.patch
 
 
-class Iterator(object):
+class Iterator():
     """Nested diff iterator."""
 
     default_iterator = DEFAULT_HANDLER.iterate_diff
 
     def __init__(self, handlers=None, sort_keys=False):
-        """
-        Initialize iterator.
+        """Initialize iterator.
 
-        If `sort_keys` is `True`, then the output for mappings will be
-        sorted by key. Disabled by default.
-
-        `handlers` is a list of type handlers.
+        Args:
+            sort_keys: Sort diff items if applicable.
+            handlers: List of type handlers.
 
         """
         self.sort_keys = sort_keys
-        self._iterators = {}
+
+        self._iters_by_cls = {}
+        self._iters_by_ext = {}
 
         for handler in TYPE_HANDLERS if handlers is None else handlers:
             self.set_handler(handler)
 
     def _get_iterator(self, ndiff):
-        """
-        Return apropriate iterator for passed nested diff.
-
-        :param ndiff: nested diff.
-
-        """
-        if 'E' in ndiff:
-            return self.default_iterator(self, ndiff)
-
+        """Return apropriate iterator for passed nested diff."""
         try:
-            return self._iterators[ndiff['D'].__class__](self, ndiff)
+            extension_id = ndiff['E']
+            try:
+                iterator = self._iters_by_ext[extension_id]
+            except KeyError:
+                raise ValueError('unsupported extension: '
+                                 + extension_id) from None
         except KeyError:
-            return self.default_iterator(self, ndiff)
+            try:
+                iterator = self._iters_by_cls[ndiff['D'].__class__]
+            except KeyError:
+                iterator = self.default_iterator
+
+        return iterator(self, ndiff)
 
     def iterate(self, ndiff):
-        """
-        Yield tuples with diff, key and subdiff for each nested diff.
+        """Iterate over nested diff.
 
-        :param ndiff: nested diff.
+        Args:
+            ndiff: Nested diff to iterate.
+
+        Yields:
+            Tuples with diff, key and subdiff for each nested diff.
 
         """
         stack = [self._get_iterator(ndiff)]
@@ -277,27 +301,31 @@ class Iterator(object):
             stack.append(self._get_iterator(subdiff))
 
     def set_handler(self, handler):
-        """
-        Set handler.
+        """Set handler.
 
-        :param handler: handlers.TypeHandler.
+        Args:
+            handler: Instance of handlers.TypeHandler.
 
         """
-        self._iterators[handler.handled_type] = handler.iterate_diff
+        self._iters_by_cls[handler.handled_type] = handler.iterate_diff
+
+        if handler.extension_id is not None:
+            self._iters_by_ext[handler.extension_id] = handler.iterate_diff
 
 
 def diff(a, b, text_diff_ctx=-1, **kwargs):
-    """
-    Return recursive diff for two passed objects.
+    """Calculate diff for two objects.
 
-    :param a: First object to diff.
-    :param b: Second object to diff.
+    Args:
+        a: First object to diff.
+        b: Second object to diff.
+        text_diff_ctx: Amount of context lines for text (multiline strings)
+            diffs. Disabled entirely when value is negative. This opt is
+            deprecated and should be avoided.
+        kwargs: Passed to Differ's constructor as is.
 
-    :param text_diff_ctx: defines amount of context lines for text (multiline
-    strings) diffs, disabled entirely when value is negative. This opt is
-    deprecated and should be avoided.
-
-    Rest kwargs passed to Differ's constructor as is.
+    Returns:
+        Tuple: equality flag and nested diff.
 
     """
     differ = Differ(**kwargs)
@@ -313,13 +341,15 @@ def diff(a, b, text_diff_ctx=-1, **kwargs):
 
 
 def patch(target, ndiff, **kwargs):
-    """
-    Return patched object.
+    """Patch object using nested diff.
 
-    :param target: Object to patch.
-    :param ndiff: Nested diff.
+    Args:
+        target: Object to patch.
+        ndiff: Nested diff.
+        kwargs: Passed to Patcher's constructor as is.
 
-    Rest kwargs passed to Patcher's constructor as is.
+    Returns:
+        Patched object.
 
     """
     return Patcher(**kwargs).patch(target, ndiff)
